partial class SR
{
	public const string CannotAddTwoItemsWithTheSameKeyToSynchronizedKeyedCollection0 = "Cannot add two items with the same key to SynchronizedKeyedCollection.";
	public const string DuplicateBehavior1 = "The value could not be added to the collection, as the collection already contains an item of the same type: '{0}'. This collection only supports one instance of each type.";
	public const string ItemDoesNotExistInSynchronizedKeyedCollection0 = "Item does not exist in SynchronizedKeyedCollection.";
	public const string SFxCollectionReadOnly = "This operation is not supported because the collection is read-only.";
	public const string SFxCollectionWrongType2 = "The collection of type {0} does not support values of type {1}.";
	public const string SFxCopyToRequiresICollection = "SynchronizedReadOnlyCollection's CopyTo only works if the underlying list implements ICollection.";
	public const string SynchronizedCollectionWrongType1 = "A value of type '{0}' cannot be added to the generic collection, because the collection has been parameterized with a different type.";
	public const string SynchronizedCollectionWrongTypeNull = "A null value cannot be added to the generic collection, because the collection has been parameterized with a value type.";
	public const string ValueMustBeInRange = "The value of this argument must fall within the range {0} to {1}.";
	public const string XmlLangAttributeMissing = "Required xml:lang attribute value is missing.";
	public const string InvalidXmlQualifiedName = "Expected XML qualified name, found '{0}'";
	public const string UnboundPrefixInQName = "Unbound prefix used in qualified name '{0}'.";
}
